@@ -29,11 +29,11 @@ try:
     # from .Function.cut_pdF_pic import get_pdf_color_page
 
 except:
-    pass
+    # pass
 
-    # from Ui.CutPdfPicUi import Ui_CutPdfPic
-    # from Function.optionDb import getOption, InsertDb
-    # from Function.cut_pdF_pic import get_pdf_color_page
+    from Ui.CutPdfPicUi import Ui_CutPdfPic
+    from Function.optionDb import getOption, InsertDb
+    from Function.cut_pdF_pic import get_pdf_color_page
 
 import sys
 import time
