@@ -178,12 +178,13 @@ class OcrFinish(QWidget, Ui_OcrFinish):
                         if num == 2:
                             #token过期使用的信号
                             # self.communication.token_singal.emit()
-                            # self.run_code = 0
+                            self.run_code = 0
                             print("这里是设置token过期要使用的")
                         num += 1
                 else:
                     print("更新成功")
         except:
+            self.run_code = 0
             traceback.print_exc()
 
     def warn_code(self):  # 关闭窗口触发以下事件
@@ -196,11 +197,12 @@ class OcrFinish(QWidget, Ui_OcrFinish):
             self.run_code = 1
 
 
+
     def startWork(self):
         self.Finishlabel.setVisible(False)
         self.OcrFinishPBar.setValue(0)
         self.OcrFinishPBar.setTextVisible(True)
-        self.run_code = 1
+        # self.run_code = 1
         self.checkToken(5, "Json保存到Sql")
         if self.run_code:
             self.warn_code()
@@ -217,7 +219,11 @@ class OcrFinish(QWidget, Ui_OcrFinish):
                 self.thread1.start()
             else:
                 print("不启动线程")
-
+        else:
+            self.WidgetColorSignal.emit("fail")
+            # self.Warn_Signal.emit("warning","请登录后使用")
+            self.QtextEdit.clear()
+            self.QtextEdit.setPlainText('请登录后使用')
 
 class RunThread(QThread):
     def __init__(self, communication):
@@ -281,7 +287,7 @@ class RunThread(QThread):
                         if num == 2:
                             #token过期要使用的信号
                             # self.communication.token_singal.emit()
-                            # self.run_code = 0
+                            self.run_code = 0
                             print("这里是设置token过期要使用的")
                         num += 1
                 else:
