@@ -68,7 +68,7 @@ class OcrParameter(QWidget, Ui_OcrParameter):
         # 设置开始线程按钮
         self.pushButton.clicked.connect(self.startOcr)
         # 设置信号用于输出
-        self.signal1.connect(self.print11)
+        self.signal1.connect(self.reloadBtn)
 
         self.token_signal.connect(self.check_token)
         self.child_token_signal.connect(self.closeMain)
@@ -198,7 +198,7 @@ class OcrParameter(QWidget, Ui_OcrParameter):
             traceback.print_exc()
 
     # 输出错误并将识别按钮设置为可以点击
-    def print11(self, p_str):
+    def reloadBtn(self, p_str):
         self.QtextEdit.insertPlainText(p_str)
 
         self.pushButton.setEnabled(True)
@@ -259,7 +259,8 @@ class NowThread(QThread):
 
         else:
             self.communication.WidgetColorSignal.emit("fail")
-            self.communication.signal2.emit("请登录后使用！")
+            # self.communication.signal2.emit("请登录后使用！")
+            self.communication.signal1.emit("请登录后使用！")
 
     #当图片大小大于所限制的大小时，会调用此方法将图片进行大小的缩放
     def cut_jpg(self, pic_path):
